import requests
import logging

from rdflib import Graph, ConjunctiveGraph

from cubicweb.rdf import RDF_MIMETYPE_TO_FORMAT


def get_graph_from_url(download_url: str, log: logging.Logger) -> Graph:
    response = requests.get(
        download_url,
        headers={"Accept": ";".join(RDF_MIMETYPE_TO_FORMAT.keys())},
        allow_redirects=True,
        timeout=4,
    )
    if not response.ok:
        log.error(
            f"Cannot get file {download_url}: {response.status_code} {response.text}"
        )
        response.raise_for_status()
    content_type = response.headers["Content-Type"]
    rdf_parse_format = content_type
    for mime_type, rdf_format in RDF_MIMETYPE_TO_FORMAT.items():
        if mime_type in content_type:
            rdf_parse_format = rdf_format
            break

    graph = ConjunctiveGraph()
    graph.parse(data=response.text, format=rdf_parse_format)
    return graph
