import {
  TableContainer,
  Paper,
  Table,
  TableHead,
  TableRow,
  TableCell,
  TableBody,
  CircularProgress,
  Typography,
} from "@mui/material";
import CheckIcon from "@mui/icons-material/Check";
import CloseIcon from "@mui/icons-material/Close";
import ScheduleIcon from "@mui/icons-material/Schedule";
import { ImportProcess } from "@/types";
import { useGetImportProcesses } from "@/hooks/useGetImportProcesses";
import { ErrorScreen } from "./ErrorScreen";
import { LoadingScreen } from "./LoadingScreen";

export interface ImprotProcessTableProps {
  dataServiceEid?: number;
  recipeEid?: number;
  projectEid?: number;
}

// TODO add logs link
export function ImportProcessTable(props: ImprotProcessTableProps) {
  const {
    data: importProcessList,
    error,
    loading,
  } = useGetImportProcesses(props);

  if (error) {
    return <ErrorScreen message={error} />;
  }

  if (loading) {
    return <LoadingScreen />;
  }

  if (!importProcessList) {
    return <ErrorScreen />;
  }

  if (importProcessList.length === 0) {
    return (
      <Typography variant="subtitle1" color={"GrayText"}>
        Aucun import process
      </Typography>
    );
  }
  return (
    <TableContainer component={Paper}>
      <Table sx={{ minWidth: 650 }} aria-label="simple table">
        <TableHead>
          <TableRow>
            <TableCell>eid</TableCell>
            <TableCell>Date</TableCell>
            <TableCell>Recette</TableCell>
            <TableCell>État</TableCell>
            <TableCell>Projet</TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {importProcessList.map((row) => (
            <TableRow key={row.eid}>
              <TableCell component="th" scope="row">
                {row.eid}
              </TableCell>
              <TableCell>{row.date}</TableCell>
              <TableCell>{row.recipe}</TableCell>
              <TableCell>
                <StateIcon state={row.state} />
              </TableCell>
              <TableCell>{row.project}</TableCell>
            </TableRow>
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  );
}

function StateIcon({ state }: { state: ImportProcess["state"] }) {
  if (state === "successful") {
    return <CheckIcon />;
  }
  if (state === "error") {
    return <CloseIcon color="error" />;
  }
  if (state === "waiting") {
    return <ScheduleIcon color="warning" />;
  }
  if (state === "ongoing") {
    return <CircularProgress size={20} />;
  }
}
